==> gtktalog_0.99.19.orig.tar.gz: gtktalog-0.99.19/src/gtktalog/config_parse.h <==
#ifndef BISON_Y_TAB_H
# define BISON_Y_TAB_H

#ifndef YYSTYPE
typedef union {
	gint		val;
	gint		toolbarstyle;
        gint            sizeformat;
	gint		vfslast_column;
	char		*string;
	gboolean        gbool;  
	GString		*gstring;
	GArray		*garray;
	GList		*glist;
	KEY_VALUE	*kv;
} yystype;
# define YYSTYPE yystype
#endif
# define	ADDEXTICON	257
# define	ADDMIMEICON	258
# define	DEFAULTDIRICON	259
# define	DEFAULTDISKICON	260
# define	DEFAULTFILEICON	261
# define	DEFAULTUNREADABLEICON	262
# define	DEFAULTVFSICON	263
# define	DEFAULTOPENEDDIRICON	264
# define	DEFAULTOPENEDDISKICON	265
# define	DEFAULTOPENEDVFSICON	266
# define	MOUNTPROGRAM	267
# define	UMOUNTPROGRAM	268
# define	EJECTPROGRAM	269
# define	MOUNTPOINT	270
# define	USESUDO	271
# define	USEAUTOMOUNT	272
# define	MOUNTRETRY	273
# define	EXTENSION	274
# define	OPTIONDUS	275
# define	OPTIONWARNMOUNT	276
# define	OPTIONEJECT	277
# define	READCDNAME	278
# define	VALIDATECDNAME	279
# define	COMPRESSIONLEVEL	280
# define	TESTVFS	281
# define	VFSEXTENSION	282
# define	MIMEEXTENSION	283
# define	MIMEVFSEXTENSION	284
# define	READINFORMATION	285
# define	DEFAULTMIMEEXTENSION	286
# define	SCANMIMETYPES	287
# define	ADDMIMETOSKIP	288
# define	USEDEFAULTMIMEPLUGIN	289
# define	DBCLICKFORINFO	290
# define	DISPLAYDIRSIZE	291
# define	DATEFORMAT	292
# define	SIZEFORMAT	293
# define	RECENTFILE	294
# define	RECENTFILESMAX	295
# define	PREVIOUSSEARCHMODE	296
# define	SAVEONLYUSEDCATEGORIES	297
# define	MAINWINDOWPOSITION	298
# define	TREEWINDOWSIZE	299
# define	FILETOLOAD	300
# define	LOADFILEATBOOT	301
# define	AUTOSAVE	302
# define	KEEPBACKUPFILE	303
# define	MINUTESBEFOREAUTOSAVE	304
# define	TOOLBARSTYLE	305
# define	NEWSEARCHTYPE	306
# define	WORKINGPATH	307
# define	STRICTALPHABETICSORT	308
# define	DISPLAYSPLASH	309
# define	STRING	310
# define	QSTRING	311
# define	GBOOLEAN	312
# define	STRINGLOCALE	313
# define	STRINGISO8601	314
# define	TOOLBAR_STYLE_INT	315
# define	SIZE_FORMAT_INT	316
# define	VFS_LAST_COLUMN_INT	317
# define	INTEGER	318
# define	EOL	319


extern YYSTYPE yylval;

#endif /* not BISON_Y_TAB_H */

==> gtktalog_1.0.4.orig.tar.gz: gtktalog-1.0.4/src/gtktalog/config_parse.h <==
#ifndef BISON_CONFIG_PARSE_H
# define BISON_CONFIG_PARSE_H

#ifndef YYSTYPE
typedef union {
	gint		val;
	gint		toolbarstyle;
        gint            sizeformat;
	gint		vfslast_column;
	char		*string;
	gboolean        gbool;  
	GString		*gstring;
	GArray		*garray;
	GList		*glist;
	KEY_VALUE	*kv;
} yystype;
# define YYSTYPE yystype
# define YYSTYPE_IS_TRIVIAL 1
#endif
# define	ADDEXTICON	257
# define	ADDMIMEICON	258
# define	DEFAULTDIRICON	259
# define	DEFAULTDISKICON	260
# define	DEFAULTFILEICON	261
# define	DEFAULTUNREADABLEICON	262
# define	DEFAULTVFSICON	263
# define	DEFAULTOPENEDDIRICON	264
# define	DEFAULTOPENEDDISKICON	265
# define	DEFAULTOPENEDVFSICON	266
# define	MOUNTPROGRAM	267
# define	UMOUNTPROGRAM	268
# define	EJECTPROGRAM	269
# define	MOUNTPOINT	270
# define	USESUDO	271
# define	USEAUTOMOUNT	272
# define	MOUNTRETRY	273
# define	EXTENSION	274
# define	OPTIONDUS	275
# define	OPTIONWARNMOUNT	276
# define	OPTIONEJECT	277
# define	READCDNAME	278
# define	VALIDATECDNAME	279
# define	COMPRESSIONLEVEL	280
# define	TESTVFS	281
# define	VFSEXTENSION	282
# define	MIMEEXTENSION	283
# define	MIMEVFSEXTENSION	284
# define	READINFORMATION	285
# define	DEFAULTMIMEEXTENSION	286
# define	SCANMIMETYPES	287
# define	ADDMIMETOSKIP	288
# define	USEDEFAULTMIMEPLUGIN	289
# define	DBCLICKFORINFO	290
# define	DISPLAYDIRSIZE	291
# define	DATEFORMAT	292
# define	SIZEFORMAT	293
# define	RECENTFILE	294
# define	RECENTFILESMAX	295
# define	PREVIOUSSEARCHMODE	296
# define	SAVEONLYUSEDCATEGORIES	297
# define	MAINWINDOWPOSITION	298
# define	TREEWINDOWSIZE	299
# define	FILETOLOAD	300
# define	LOADFILEATBOOT	301
# define	AUTOSAVE	302
# define	KEEPBACKUPFILE	303
# define	MINUTESBEFOREAUTOSAVE	304
# define	TOOLBARSTYLE	305
# define	NEWSEARCHTYPE	306
# define	WORKINGPATH	307
# define	STRICTALPHABETICSORT	308
# define	DISPLAYSPLASH	309
# define	STRING	310
# define	QSTRING	311
# define	GMALLOC_STRING	312
# define	GBOOLEAN	313
# define	STRINGLOCALE	314
# define	STRINGISO8601	315
# define	TOOLBAR_STYLE_INT	316
# define	SIZE_FORMAT_INT	317
# define	VFS_LAST_COLUMN_INT	318
# define	INTEGER	319
# define	EOL	320


extern YYSTYPE yylval;

#endif /* not BISON_CONFIG_PARSE_H */
